@@ -191,14 +191,10 @@ fn calc_crc(data: &[u8]) -> u16 {
     for x in data {
         crc ^= u16::from(*x);
         for _ in 0..8 {
-            // if we followed clippy's suggestion to move out the crc >>= 1, the condition may not be met any more
-            // the recommended action therefore makes no sense and it is better to allow this lint
-            #[allow(clippy::branches_sharing_code)]
-            if (crc & 0x0001) != 0 {
-                crc >>= 1;
+            let crc_odd = (crc & 0x0001) != 0;
+            crc >>= 1;
+            if crc_odd {
                 crc ^= 0xA001;
-            } else {
-                crc >>= 1;
             }
         }
     }
@@ -206,7 +202,7 @@ fn calc_crc(data: &[u8]) -> u16 {
 }
 
 fn check_crc(adu_data: &[u8], expected_crc: u16) -> Result<()> {
-    let actual_crc = calc_crc(&adu_data);
+    let actual_crc = calc_crc(adu_data);
     if expected_crc != actual_crc {
         return Err(Error::new(
             ErrorKind::InvalidData,
@@ -346,8 +342,7 @@ impl Decoder for ServerCodec {
     }
 }
 
-impl Encoder for ClientCodec {
-    type Item = RequestAdu;
+impl Encoder<RequestAdu> for ClientCodec {
     type Error = Error;
 
     fn encode(&mut self, adu: RequestAdu, buf: &mut BytesMut) -> Result<()> {
@@ -372,8 +367,7 @@ impl Encoder for ClientCodec {
     }
 }
 
-impl Encoder for ServerCodec {
-    type Item = ResponseAdu;
+impl Encoder<ResponseAdu> for ServerCodec {
     type Error = Error;
 
     fn encode(&mut self, adu: ResponseAdu, buf: &mut BytesMut) -> Result<()> {
